==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/GXModules/Gambio/CookieConsentPanel/TextPhrases/english/cookie_consent_panel.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   cookie_consent_panel.lang.inc.php 2019-12-18
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'title'                                    => 'Cookie Consent',
    'description'                              => 'Display a cookie consent panel',
    'texts'                                    => 'Texts',
    'label_intro_heading'                      => 'Headline of the layer',
    'label_intro'                              => 'Text of the layer',
    'label_button_yes'                         => 'Label of the consent button',
    'label_button_yes_all'                     => 'Label of the consent all button',
    'label_button_back'                        => 'Label of the back button in cookie preference center',
    'label_button_advanced_settings'           => 'Text of the link to the cookie preference center',
    'label_cpc_heading'                        => 'Headline of the cookie preference center',
    'label_cpc_text'                           => 'Intro text of the cookie preference center',
    'label_cpc_activate_all'                   => 'Label of the button that activates all purposes',
    'label_cpc_deactivate_all'                 => 'Label of the button that deactivates all purposes',
    'label_cpc_purpose_desc'                   => 'Headline of the purposes section (standard CPC) or its intro text (Tab-based CPC)',
    'label_cpc_purpose_optout_confirm_heading' => 'Headline of the opt-out confirmation dialog',
    'label_cpc_purpose_optout_confirm_text'    => 'Text of the opt-out confirmation dialog',
    'label_cpc_purpose_optout_confirm_proceed' => 'Confirmation button label of the opt-out confirmation dialog',
    'label_cpc_purpose_optout_confirm_cancel'  => 'Cancel button label of the opt-out confirmation dialog',
    'label_nocookie_head'                      => 'Headline that is shown if user has disallowed all cookies',
    'label_nocookie_text'                      => 'Text that is shown if user has disallowed all cookies',
    'label_poi_group_list_heading'             => 'Headline for POI group section',
    'label_poi_group_list_text'                => 'Text for POI group section',
    'label_third_party'                        => 'Headline of the vendors section in CPC',
    'label_cpc_purpose_01_text'                => 'Label for technical cookies',
    'label_cpc_purpose_01_desc'                => 'Description for technical cookies',
    'label_cpc_purpose_02_text'                => 'Label for payment modules cookies',
    'label_cpc_purpose_02_desc'                => 'Description for payment modules cookies',
    'label_cpc_purpose_03_text'                => 'Label for tracking cookies',
    'label_cpc_purpose_03_desc'                => 'Description for tracking cookies',
    'label_cpc_purpose_04_text'                => 'Label for tracking cookies',
    'label_cpc_purpose_04_desc'                => 'Description for tracking cookies',
    'label_cpc_purpose_05_text'                => 'Label for tracking cookies',
    'label_cpc_purpose_05_desc'                => 'Description for tracking cookies',
    'label_cpc_category_01_text'               => 'Name of the first consent category',
    'label_cpc_category_02_text'               => 'Name of the second consent category',
    'label_cpc_category_03_text'               => 'Name of the third consent category',
    'label_cpc_category_04_text'               => 'Name of the fourth consent category',
    'label_cpc_category_05_text'               => 'Name of the fifth consent category',
    'label_cpc_category_01_desc'               => 'Description of the first consent category',
    'label_cpc_category_02_desc'               => 'Description of the second consent category',
    'label_cpc_category_03_desc'               => 'Description of the third consent category',
    'label_cpc_category_04_desc'               => 'Description of the fourth consent category',
    'label_cpc_category_05_desc'               => 'Description of the fifth consent category',
    
    'label_cpc_categories_tab'   => 'Categories',
    'label_cpc_purposes_tab'     => 'Purposes',
    'label_category'             => 'Category',
    'label_category_title'       => 'Title',
    'label_category_description' => 'Description',
    
    'label_purpose_button_create_new'  => 'Add new purpose',
    'label_purpose_modal_title_create' => 'Create a new Purpose',
    'label_purpose_modal_title_edit'   => 'Edit Purpose',
    'label_purpose_status'             => 'Status',
    'label_purpose_title'              => 'Title',
    'label_purpose_description'        => 'Description',
    
    'label_cpc_button_create' => 'Create',
    'label_cpc_button_save'   => 'Save',
    'label_cpc_button_edit'   => 'Edit',
    'label_cpc_button_update' => 'Update',
    'label_cpc_button_delete' => 'Delete',
    'label_cpc_button_cancel' => 'Cancel',

    'label_show_integration'           => 'Display integration',
    'integration_your_code'            => 'Your Javascript code',
    'integration_script_path'          => 'Path to your Javascript',
    'integration_your_code_headline'   => 'Integration of directly integrated code',
    'integration_script_path_headline' => 'Integration of loaded code',

    'label_cpc_general_tab'                    => 'General',
    'label_cpc_delete_modal_title'             => 'Delete purpose',
    'label_cpc_delete_modal_content'           => 'Are you sure you want to delete this purpose?',
    'label_cpc_footer_link_text'               => 'Cookie Settings',

    'error_message_missing_title' => 'A title must be supplied for every language.',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GXModules/Gambio/CookieConsentPanel/TextPhrases/english/cookie_consent_panel.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   cookie_consent_panel.lang.inc.php 2021-12-07
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'title'                                    => 'Cookie Consent',
    'description'                              => 'Display a cookie consent panel',
    'texts'                                    => 'Texts',
    'label_intro_heading'                      => 'Headline of the layer',
    'label_intro'                              => 'Text of the layer',
    'label_button_yes'                         => 'Label of the consent button',
    'label_button_yes_all'                     => 'Label of the consent all button',
    'label_button_only_essentials'             => 'Label of the consent only essentials button',
    'label_button_back'                        => 'Label of the back button in cookie preference center',
    'label_button_advanced_settings'           => 'Text of the link to the cookie preference center',
    'label_cpc_heading'                        => 'Headline of the cookie preference center',
    'label_cpc_text'                           => 'Intro text of the cookie preference center',
    'label_cpc_activate_all'                   => 'Label of the button that activates all purposes',
    'label_cpc_deactivate_all'                 => 'Label of the button that deactivates all purposes',
    'label_cpc_purpose_desc'                   => 'Headline of the purposes section (standard CPC) or its intro text (Tab-based CPC)',
    'label_cpc_purpose_optout_confirm_heading' => 'Headline of the opt-out confirmation dialog',
    'label_cpc_purpose_optout_confirm_text'    => 'Text of the opt-out confirmation dialog',
    'label_cpc_purpose_optout_confirm_proceed' => 'Confirmation button label of the opt-out confirmation dialog',
    'label_cpc_purpose_optout_confirm_cancel'  => 'Cancel button label of the opt-out confirmation dialog',
    'label_nocookie_head'                      => 'Headline that is shown if user has disallowed all cookies',
    'label_nocookie_text'                      => 'Text that is shown if user has disallowed all cookies',
    'label_poi_group_list_heading'             => 'Headline for POI group section',
    'label_poi_group_list_text'                => 'Text for POI group section',
    'label_third_party'                        => 'Headline of the vendors section in CPC',
    'label_cpc_purpose_01_text'                => 'Label for technical cookies',
    'label_cpc_purpose_01_desc'                => 'Description for technical cookies',
    'label_cpc_purpose_02_text'                => 'Label for payment modules cookies',
    'label_cpc_purpose_02_desc'                => 'Description for payment modules cookies',
    'label_cpc_purpose_03_text'                => 'Label for tracking cookies',
    'label_cpc_purpose_03_desc'                => 'Description for tracking cookies',
    'label_cpc_purpose_04_text'                => 'Label for tracking cookies',
    'label_cpc_purpose_04_desc'                => 'Description for tracking cookies',
    'label_cpc_purpose_05_text'                => 'Label for tracking cookies',
    'label_cpc_purpose_05_desc'                => 'Description for tracking cookies',
    'label_cpc_category_01_text'               => 'Name of the first consent category',
    'label_cpc_category_02_text'               => 'Name of the second consent category',
    'label_cpc_category_03_text'               => 'Name of the third consent category',
    'label_cpc_category_04_text'               => 'Name of the fourth consent category',
    'label_cpc_category_05_text'               => 'Name of the fifth consent category',
    'label_cpc_category_01_desc'               => 'Description of the first consent category',
    'label_cpc_category_02_desc'               => 'Description of the second consent category',
    'label_cpc_category_03_desc'               => 'Description of the third consent category',
    'label_cpc_category_04_desc'               => 'Description of the fourth consent category',
    'label_cpc_category_05_desc'               => 'Description of the fifth consent category',
    
    'label_cpc_categories_tab'   => 'Categories',
    'label_cpc_purposes_tab'     => 'Purposes',
    'label_category'             => 'Category',
    'label_category_title'       => 'Title',
    'label_category_description' => 'Description',
    
    'label_purpose_button_create_new'     => 'Add new purpose',
    'label_purpose_modal_title_create'    => 'Create a new Purpose',
    'label_purpose_modal_title_edit'      => 'Edit Purpose',
    'label_purpose_status'                => 'Status',
    'label_only_essentials_button_status' => 'Show "Only Essentials" button',
    'label_purpose_title'                 => 'Title',
    'label_purpose_description'           => 'Description',
    
    'label_cpc_button_create' => 'Create',
    'label_cpc_button_save'   => 'Save',
    'label_cpc_button_edit'   => 'Edit',
    'label_cpc_button_update' => 'Update',
    'label_cpc_button_delete' => 'Delete',
    'label_cpc_button_cancel' => 'Cancel',

    'label_show_integration'           => 'Display integration',
    'integration_your_code'            => 'Your Javascript code',
    'integration_script_path'          => 'Path to your Javascript',
    'integration_your_code_headline'   => 'Integration of directly integrated code',
    'integration_script_path_headline' => 'Integration of loaded code',

    'label_cpc_general_tab'                    => 'General',
    'label_cpc_delete_modal_title'             => 'Delete purpose',
    'label_cpc_delete_modal_content'           => 'Are you sure you want to delete this purpose?',
    'label_cpc_footer_link_text'               => 'Cookie Settings',

    'error_message_missing_title' => 'A title must be supplied for every language.',
];
